Loads the information of episodes, or annotated physiological events, and stores it into the data structure containing the beat positions
LoadEpisodesAscii(HRVData, FileName, RecordPath=".", Tag="", InitTime="0:0:0",
verbose=NULL,header = TRUE)Data structure that stores the beats register and information related to it
The episodes file to be used
The path of the file
Type of episode
Time (HH:MM:SS)
Deprecated argument maintained for compatibility, use SetVerbose() instead
Logical value. If TRUE, then the first line of the file is skipped. Default: TRUE.
Returns HRVData, the structure that contains beat positions register and episodes information
L. Rodriguez-Linares, A. Mendez, M. Lado, D. Olivieri, X. Vila, I. Gomez-Conde, "An open source tool for heart rate variability spectral analysis", Computer Methods and Programs in Biomedicine 103, 39-50, doi:10.1016/j.cmpb.2010.05.012 (2011)